@@ -231,8 +231,9 @@ _gcr_gnupg_process_class_init (GcrGnupgProcessClass *klass)
 	 * ~/.gnupg/ directory.
 	 */
 	g_object_class_install_property (gobject_class, PROP_DIRECTORY,
-	           g_param_spec_string ("directory", "Directory", "Gnupg Directory",
-	                                NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+		g_param_spec_string ("directory", "Directory", "Gnupg Directory",
+		                     NULL,
+		                     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrGnupgProcess:executable:
@@ -240,8 +241,9 @@ _gcr_gnupg_process_class_init (GcrGnupgProcessClass *klass)
 	 * Path to the gnupg executable, or %NULL for default.
 	 */
 	g_object_class_install_property (gobject_class, PROP_EXECUTABLE,
-	           g_param_spec_string ("executable", "Executable", "Gnupg Executable",
-	                                GPG_EXECUTABLE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+		g_param_spec_string ("executable", "Executable", "Gnupg Executable",
+		                     GPG_EXECUTABLE,
+		                     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrGnupgProcess:input-stream:
@@ -249,8 +251,9 @@ _gcr_gnupg_process_class_init (GcrGnupgProcessClass *klass)
 	 * Input for gnupg, or %NULL for no input.
 	 */
 	g_object_class_install_property (gobject_class, PROP_INPUT_STREAM,
-	           g_param_spec_object ("input-stream", "Input Stream", "Input Stream",
-	                                G_TYPE_INPUT_STREAM, G_PARAM_READWRITE));
+		g_param_spec_object ("input-stream", "Input Stream", "Input Stream",
+		                     G_TYPE_INPUT_STREAM,
+		                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrGnupgProcess:output-stream:
@@ -258,8 +261,9 @@ _gcr_gnupg_process_class_init (GcrGnupgProcessClass *klass)
 	 * Output from gnupg, or %NULL for ignored output.
 	 */
 	g_object_class_install_property (gobject_class, PROP_OUTPUT_STREAM,
-	           g_param_spec_object ("output-stream", "Output Stream", "Output Stream",
-	                                G_TYPE_OUTPUT_STREAM, G_PARAM_READWRITE));
+		g_param_spec_object ("output-stream", "Output Stream", "Output Stream",
+		                     G_TYPE_OUTPUT_STREAM,
+		                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrGnupgProcess:attribute-stream:
@@ -267,8 +271,9 @@ _gcr_gnupg_process_class_init (GcrGnupgProcessClass *klass)
 	 * Output of attribute data from gnupg, or %NULL for ignored attributes.
 	 */
 	g_object_class_install_property (gobject_class, PROP_ATTRIBUTE_STREAM,
-	           g_param_spec_object ("attribute-stream", "Attribute Stream", "Attribute Stream",
-	                                G_TYPE_OUTPUT_STREAM, G_PARAM_READWRITE));
+		g_param_spec_object ("attribute-stream", "Attribute Stream", "Attribute Stream",
+		                     G_TYPE_OUTPUT_STREAM,
+		                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrGnupgProcess::error-line:
@@ -317,8 +322,8 @@ _gcr_gnupg_process_init_async (GAsyncResultIface *iface)
 
 /**
  * _gcr_gnupg_process_new:
- * @directory: (allow-none): The gnupg home directory
- * @executable: (allow-none): The gpg executable
+ * @directory: (nullable): The gnupg home directory
+ * @executable: (nullable): The gpg executable
  *
  * Create a new GcrGnupgProcess.
  *
@@ -934,9 +939,9 @@ on_cancellable_cancelled (GCancellable *cancellable, gpointer user_data)
  * _gcr_gnupg_process_run_async:
  * @self: The process
  * @argv: (array zero-terminated=1): The arguments for the process, not including executable, terminated with %NULL.
- * @envp: (allow-none) (array zero-terminated=1): The environment for new process, terminated with %NULL.
+ * @envp: (nullable) (array zero-terminated=1): The environment for new process, terminated with %NULL.
  * @flags: Flags for starting the process.
- * @cancellable: (allow-none): Cancellation object
+ * @cancellable: (nullable): Cancellation object
  * @callback: Will be called when operation completes.
  * @user_data: (closure): Data passed to callback.
  *
