@@ -358,7 +358,8 @@ gcr_viewer_widget_class_init (GcrViewerWidgetClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_PARSER,
 	           g_param_spec_object ("parser", "Parser", "Parser used to parse viewable items",
-	                                GCR_TYPE_PARSER, G_PARAM_READABLE));
+	                                GCR_TYPE_PARSER,
+	                                G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrViewerWidget:display-name:
@@ -371,7 +372,8 @@ gcr_viewer_widget_class_init (GcrViewerWidgetClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_DISPLAY_NAME,
 	            g_param_spec_string ("display-name", "Display name", "Display name",
-	                                 NULL, G_PARAM_READWRITE));
+	                                 NULL,
+	                                 G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrViewerWidget::added:
@@ -529,7 +531,7 @@ gcr_viewer_widget_load_file (GcrViewerWidget *self,
 /**
  * gcr_viewer_widget_load_bytes:
  * @self: a viewer widget
- * @display_name: (allow-none): label for the loaded data
+ * @display_name: (nullable): label for the loaded data
  * @data: data to load
  *
  * Parse and load some data to be displayed into the viewer widgets. The data
@@ -561,7 +563,7 @@ gcr_viewer_widget_load_bytes (GcrViewerWidget *self,
 /**
  * gcr_viewer_widget_load_data:
  * @self: a viewer widget
- * @display_name: (allow-none): label for the loaded data
+ * @display_name: (nullable): label for the loaded data
  * @data: (array length=n_data): data to load
  * @n_data: length of data to load
  *
@@ -621,7 +623,7 @@ gcr_viewer_widget_get_parser (GcrViewerWidget *self)
  * gcr_viewer_widget_show_error:
  * @self: a viewer widget
  * @message: descriptive error message
- * @error: (allow-none): detailed error
+ * @error: (nullable): detailed error
  *
  * Show an error on the viewer widget. This is displayed on a info bar near
  * the edge of the widget.
